==> php54-owncloud-8.0.4.tgz: share/owncloud/apps/activity/l10n/fi_FI.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Toimet",
    "Your settings have been updated." : "Asetuksesi on päivitetty.",
    "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
    "A new file or folder has been <strong>created</strong>" : "Uusi tiedosto tai kansio on <strong>luotu</strong>",
    "A file or folder has been <strong>changed</strong>" : "Tiedostoa tai kansiota on <strong>muutettu</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Tiedosto tai kansio on <strong>poistettu</strong>",
    "A file or folder has been <strong>restored</strong>" : "Tiedosto tai kansio on <strong>palautettu</strong>",
    "You created %1$s" : "Loit kohteen %1$s",
    "%2$s created %1$s" : "%2$s loi kohteen %1$s",
    "%1$s was created in a public folder" : "%1$s luotiin julkiseen kansioon",
    "You changed %1$s" : "Muutit kohdetta %1$s",
    "%2$s changed %1$s" : "%2$s muutti kohdetta %1$s",
    "You deleted %1$s" : "Poistit kohteen %1$s",
    "%2$s deleted %1$s" : "%2$s poisti kohteen %1$s",
    "You restored %1$s" : "Palautit kohteen %1$s",
    "%2$s restored %1$s" : "%2$s palautti kohteen %1$s",
    "You shared %1$s with %2$s" : "Jaoit kohteen %1$s käyttäjän %2$s kanssa",
    "You shared %1$s with group %2$s" : "Jaoit kohteen %1$s ryhmän %2$s kanssa",
    "%2$s shared %1$s with you" : "%2$s jakoi kohteen %1$s kanssasi",
    "You shared %1$s via link" : "Jaoit kohteen %1$s linkin kautta",
    "Activity notification" : "Ilmoitus toiminnasta",
    "All Activities" : "Kaikki toimet",
    "Activities by you" : "Omat toimet",
    "Activities by others" : "Muiden toimet",
    "Shares" : "Jaot",
    "Files" : "Tiedostot",
    "\"remote user\"" : "\"etäkäyttäjä\"",
    "in %s" : "polussa %s",
    "%s and %s" : "%s ja %s",
    ", " : ", ",
    "%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>::%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>" : ["%s ja <strong class=\"tooltip\" title=\"%s\">%n lisää</strong>","%s ja <strong class=\"tooltip\" title=\"%s\">%n lisää</strong>"],
    "%s and %n more::%s and %n more" : ["%s ja %n lisää","%s ja %n lisää"],
    "Hello %s," : "Hei %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Saat tämän sähköpostiviestin, koska seuraavat asiat tapahtuivat kohteessa %s viimeisimmän tunnin aikana.",
    "You are receiving this email because in the last day the following things happened at %s" : "Saat tämän sähköpostiviestin, koska seuraavat asiat tapahtuivat kohteessa %s viimeisimmän vuorokauden aikana.",
    "You are receiving this email because in the last week the following things happened at %s" : "Saat tämän sähköpostiviestin, koska seuraavat asiat tapahtuivat kohteessa %s viime viikon aikana.",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "You will see a list of events here when you start to use your %s." : "Näet tapahtumaluettelon täällä, kun aloitat %sin käytön.",
    "No more events to load" : "Ei enempää tapahtumia ladattavaksi",
    "Enable RSS feed" : "Käytä RSS-syötettä",
    "Notifications" : "Ilmoitukset",
    "Mail" : "Sähköposti",
    "Stream" : "Jono",
    "List your own actions in the stream" : "Listaa omat toimet jonossa",
    "Notify about your own actions via email" : "Ilmoita omista toimista sähköpostitse",
    "You need to set up your email address before you can receive notification emails." : "Aseta sähköpostiosoite, jotta voit vastaanottaa sähköposti-ilmoituksia.",
    "Send emails:" : "Lähetä sähköpostit:",
    "Hourly" : "Tunneittain",
    "Daily" : "Päivittäin",
    "Weekly" : "Viikottain",
    "Activity feed" : "Toiminnan syöte",
    "Personal activity feed for %s" : "Käyttäjän %s henkilökohtainen toimintasyöte"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/activity/l10n/fi_FI.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Toimet",
    "Personal activity feed for %s" : "Käyttäjän %s henkilökohtainen toimintasyöte",
    "Your feed URL is invalid" : "Syöteosoitteesi on virheellinen",
    "Your settings have been updated." : "Asetuksesi on päivitetty.",
    "This stream will show events like additions, changes & shares" : "Tähän luetteloon ilmestyy tapahtumakuvauksia, kuten lisäyksiä, muutoksia ja jakamisia",
    "There are no events for this filter" : "Tällä suodattimella ei ole näytettäviä tapahtumia",
    "Activity notification" : "Ilmoitus toiminnasta",
    "All Activities" : "Kaikki toimet",
    "Activities by you" : "Omat toimet",
    "Activities by others" : "Muiden toimet",
    "\"remote user\"" : "\"etäkäyttäjä\"",
    "in %s" : "polussa %s",
    "%s and %s" : "%s ja %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s ja <strong class=\"tooltip\" title=\"%s\">%n lisää</strong>","%s ja <strong class=\"tooltip\" title=\"%s\">%n lisää</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s ja %n lisää","%s ja %n lisää"],
    "Hello %s," : "Hei %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Saat tämän sähköpostiviestin, koska seuraavat asiat tapahtuivat kohteessa %s viimeisimmän tunnin aikana.",
    "You are receiving this email because in the last day the following things happened at %s" : "Saat tämän sähköpostiviestin, koska seuraavat asiat tapahtuivat kohteessa %s viimeisimmän vuorokauden aikana.",
    "You are receiving this email because in the last week the following things happened at %s" : "Saat tämän sähköpostiviestin, koska seuraavat asiat tapahtuivat kohteessa %s viime viikon aikana.",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* ja %n lisää","* ja %n lisää"],
    "Notifications" : "Ilmoitukset",
    "Mail" : "Sähköposti",
    "Stream" : "Jono",
    "List your own actions in the stream" : "Listaa omat toimet jonossa",
    "Notify about your own actions via email" : "Ilmoita omista toimista sähköpostitse",
    "You need to set up your email address before you can receive notification emails." : "Aseta sähköpostiosoite, jotta voit vastaanottaa sähköposti-ilmoituksia.",
    "Send emails:" : "Lähetä sähköpostit:",
    "Hourly" : "Tunneittain",
    "Daily" : "Päivittäin",
    "Weekly" : "Viikottain",
    "Activity feed" : "Toiminnan syöte",
    "Enable RSS feed" : "Käytä RSS-syötettä",
    "No activity yet" : "Ei toimia vielä",
    "No more events to load" : "Ei enempää tapahtumia ladattavaksi",
    "Files" : "Tiedostot"
},
"nplurals=2; plural=(n != 1);");
